summaryrefslogtreecommitdiffstats
path: root/net/http/http_auth_handler.cc
diff options
context:
space:
mode:
Diffstat (limited to 'net/http/http_auth_handler.cc')
-rw-r--r--net/http/http_auth_handler.cc10
1 files changed, 6 insertions, 4 deletions
diff --git a/net/http/http_auth_handler.cc b/net/http/http_auth_handler.cc
index dd9482f..6dac1f0 100644
--- a/net/http/http_auth_handler.cc
+++ b/net/http/http_auth_handler.cc
@@ -12,15 +12,17 @@ bool HttpAuthHandler::InitFromChallenge(std::string::const_iterator begin,
HttpAuth::Target target) {
target_ = target;
score_ = -1;
+ properties_ = -1;
bool ok = Init(begin, end);
// Init() is expected to set the scheme, realm, and score.
DCHECK(!ok || !scheme().empty());
- DCHECK(!ok || !realm().empty());
DCHECK(!ok || score_ != -1);
-
+ DCHECK(!ok || properties_ != -1);
+
return ok;
}
-} // namespace net
+} // namespace net
@@ -12,15 +12,17 @@ bool HttpAuthHandler::InitFromChallenge(std::string::const_iterator begin,
bool ok = Init(begin, end);
- // Init() is expected to set the scheme, realm, and score.
+ // Init() is expected to set the scheme, realm, score, and properties. The
+ // realm may be empty.
DCHECK(!ok || !scheme().empty());